==> mozilla-source-0.9.9.tar.bz2: mozilla/content/xsl/document/src/nsTransformMediator.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Communicator client code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef nsTransformMediator_h__
#define nsTransformMediator_h__

#include "nsITransformMediator.h"
#include "nsIDocumentTransformer.h"
#include "nsIDOMNode.h"
#include "nsIDOMDocument.h"
#include "nsIObserver.h"

class nsTransformMediator : public nsITransformMediator {
public:
  nsTransformMediator();
  virtual ~nsTransformMediator();

  nsresult Init(const nsACString& aMimeType);

  // nsISupports
  NS_DECL_ISUPPORTS

  // nsITransformMediator
  NS_IMETHOD SetEnabled(PRBool aValue);
  NS_IMETHOD SetSourceContentModel(nsIDOMNode* aSource);  
  NS_IMETHOD SetStyleSheetContentModel(nsIDOMNode* aStyle);
  NS_IMETHOD SetResultDocument(nsIDOMDocument* aDoc);
  NS_IMETHOD GetResultDocument(nsIDOMDocument** aDoc);
  NS_IMETHOD SetTransformObserver(nsIObserver* aObserver);

protected:
  void TryToTransform();

  PRBool mEnabled;
  nsCOMPtr<nsIDocumentTransformer> mTransformer; // Strong reference
  nsCOMPtr<nsIDOMNode> mSourceDOM;               // Strong reference
  nsCOMPtr<nsIDOMNode> mStyleDOM;                // Strong reference
  nsCOMPtr<nsIDOMDocument> mResultDoc;           // Strong reference
  nsCOMPtr<nsIObserver> mObserver;               // Strong reference
};

#endif // nsTransformMediator_h__

==> mozilla-source-1.3.tar.bz2: mozilla/content/xsl/document/src/nsTransformMediator.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: NPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Netscape Public License
 * Version 1.1 (the "License"); you may not use this file except in
 * compliance with the License. You may obtain a copy of the License at
 * http://www.mozilla.org/NPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Mozilla Communicator client code.
 *
 * The Initial Developer of the Original Code is 
 * Netscape Communications Corporation.
 * Portions created by the Initial Developer are Copyright (C) 1998
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the NPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the NPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef nsTransformMediator_h__
#define nsTransformMediator_h__

#include "nsCOMPtr.h"
#include "nsITransformMediator.h"
#include "nsIDocumentTransformer.h"
#include "nsIDOMNode.h"
#include "nsIDOMDocument.h"

class nsTransformMediator : public nsITransformMediator {
public:
  nsTransformMediator();
  virtual ~nsTransformMediator();

  nsresult Init(const nsACString& aMimeType);

  // nsISupports
  NS_DECL_ISUPPORTS

  // nsITransformMediator
  NS_IMETHOD SetEnabled(PRBool aValue);
  NS_IMETHOD SetSourceContentModel(nsIDOMNode* aSource);  
  NS_IMETHOD SetStyleSheetContentModel(nsIDOMNode* aStyle);
  NS_IMETHOD GetResultDocument(nsIDOMDocument** aDoc);
  NS_IMETHOD SetTransformObserver(nsITransformObserver* aObserver);
  NS_IMETHOD SetStyleInvalid(PRBool aInvalid);

protected:
  void TryToTransform();

  PRBool mEnabled;
  PRBool mStyleInvalid;
  nsCOMPtr<nsIDocumentTransformer> mTransformer;
  nsCOMPtr<nsIDOMNode> mSourceDOM;
  nsCOMPtr<nsIDOMNode> mStyleDOM;
  nsCOMPtr<nsIDOMDocument> mResultDoc;
  nsCOMPtr<nsITransformObserver> mObserver;
};

#endif // nsTransformMediator_h__
